<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;

class Document extends Model {

    public $table = 'documents';
    public $primaryKey = 'id';

    protected $fillable = [
        'path',
        'extension',
        'size'
    ];

    public function product(): belongsTo {
        return $this->belongsTo(Product::class);
    }

}
